@@ -31,9 +31,9 @@ __version__ = "1.1"
 __license__ = "Python"
 __author__ = "Bas van Oostveen <v.oostveen@gmail.com>",
 __contributors__ = [
-    "Antonio Cavedoni <http://cavedoni.com/>"
-    "Stefano J. Attardi <http://attardi.org/>",
-    "limodou <http://www.donews.net/limodou/>",
+    "Antonio Cavedoni <https://cavedoni.com/>"
+    "Stefano J. Attardi <https://attardi.org/>",
+    "limodou",
     "Carlo C8E Miron",
     "Andre Campos <cahenan@gmail.com>",
     "Justin Findlay <jfindlay@gmail.com>",
